summaryrefslogtreecommitdiff
path: root/src/script/api/script_log.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_log.hpp')
-rw-r--r--src/script/api/script_log.hpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/script/api/script_log.hpp b/src/script/api/script_log.hpp
index e352e232c..ba5a5f025 100644
--- a/src/script/api/script_log.hpp
+++ b/src/script/api/script_log.hpp
@@ -17,10 +17,10 @@
/**
* Class that handles all log related functions.
*/
-class AILog : public AIObject {
- /* AIController needs access to Enum and Log, in order to keep the flow from
+class ScriptLog : public ScriptObject {
+ /* ScriptController needs access to Enum and Log, in order to keep the flow from
* OpenTTD core to NoAI API clear and simple. */
- friend class AIController;
+ friend class ScriptController;
public:
#ifndef EXPORT_SKIP
@@ -28,7 +28,7 @@ public:
* Log levels; The value is also feed to DEBUG() lvl.
* This has no use for you, as AI writer.
*/
- enum AILogType {
+ enum ScriptLogType {
LOG_SQ_ERROR = 0, ///< Squirrel printed an error.
LOG_ERROR = 1, ///< User printed an error.
LOG_SQ_INFO = 2, ///< Squirrel printed some info.
@@ -42,7 +42,7 @@ public:
*/
struct LogData {
char **lines; ///< The log-lines.
- AILog::AILogType *type; ///< Per line, which type of log it was.
+ ScriptLog::ScriptLogType *type; ///< Per line, which type of log it was.
int count; ///< Total amount of log-lines possible.
int pos; ///< Current position in lines.
int used; ///< Total amount of used log-lines.
@@ -79,7 +79,7 @@ private:
/**
* Internal command to log the message in a common way.
*/
- static void Log(AILog::AILogType level, const char *message);
+ static void Log(ScriptLog::ScriptLogType level, const char *message);
};
#endif /* SCRIPT_LOG_HPP */